@@ -1,3 +1,5 @@
+from typing import List
+
 from sym.cli.actions.sym_action import SymAction
 from sym.cli.data.request_data import RequestData
 from sym.cli.helpers.ansible import run_ansible
@@ -9,7 +11,7 @@ class AnsiblePlaybookAction(SymAction):
     def __init__(self):
         super().__init__("ansible_playbook")
 
-    def get_requirements(self) -> [SymCheck]:
+    def get_requirements(self) -> List[SymCheck]:
         return [
             DependenciesCheck("aws"),
             DependenciesCheck("session-manager-plugin"),
@@ -27,6 +29,7 @@ class AnsiblePlaybookAction(SymAction):
         client = SAMLClientFactory.create_saml_client(
             request_data.resource, global_options
         )
+        client.send_analytics_event()
 
         run_ansible(
             client,
@@ -37,4 +40,5 @@ class AnsiblePlaybookAction(SymAction):
             control_master=ansible_options.control_master,
             send_command=ansible_options.send_command,
             forks=ansible_options.forks,
+            ssm_timeout=ansible_options.ssm_timeout,
         )
