@@ -4,12 +4,13 @@ import tempfile
 from pathlib import Path
 
 import click
+from sym.shared.cli.helpers.contexts import push_envs
 
+from sym.cli.decorators import loses_interactivity, require_login
+from sym.cli.helpers.config import Config
+from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
-from ..decorators import loses_interactivity, require_login
-from ..helpers.config import Config
-from ..helpers.contexts import push_envs
 from ..helpers.doctor import (
     AnsibleDoctorRunner,
     check_saml_client,
@@ -21,7 +22,6 @@ from ..helpers.doctor import (
     write_versions_pip,
     zip_logs,
 )
-from ..helpers.global_options import GlobalOptions
 from ..helpers.options import resource_argument
 from .sym import sym
 
