@@ -11,3 +11,6 @@ Saml2AwsNoRoles = re.compile(
     "no (?:account|role)s available|Supplied RoleArn not found in saml assertion"
 )
 Saml2AwsNoCreds = re.compile("aws credentials not found")
+Saml2AwsCredsExpired = re.compile("aws credentials have expired")
+
+CLI_PACKAGE_NAME = "sym-cli"
