@@ -15,6 +15,7 @@ class GlobalOptions(GlobalOptionsBase):
     saml_clients: Dict[str, SAMLClient] = field(default_factory=dict)
     session_length: Optional[int] = None
     aws_region: Optional[str] = None
+    disable_caches: bool = False
 
     def to_dict(self):
         return {
@@ -22,4 +23,5 @@ class GlobalOptions(GlobalOptionsBase):
             "saml_client": str(self.saml_client_type),
             "session_length": str(self.session_length),
             "aws_region": str(self.aws_region),
+            "disable_caches": self.disable_caches,
         }
