@@ -99,9 +99,9 @@ LaunchDarklyParams: OrgParams = {
         "intuit-dr": Profile(
             display_name="Intuit: DR",
             region="us-east-2",
-            arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-intuit-dr",
+            arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-dr",
             ansible_bucket="launchdarkly-sym-ansible-intuit-dr",
-            aliases=["intuit_dr"],
+            aliases=["intuit_dr", "intuit_production_dr"],
         ),
         "intuit-staging": Profile(
             display_name="Intuit: Staging",
